RemoteServerInfo class

Constructors

RemoteServerInfo({required String version, required int port, required XRayPlatform platform, required List<RemoteInspectorInfo> inspectors})
const
RemoteServerInfo.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
inspectors List<RemoteInspectorInfo>
final
platform XRayPlatform
final
port int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited