XRayInspectorProtocol class

Shared protocol constants used by both the inspector server and client.

Constructors

XRayInspectorProtocol()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultDiscoveryPort → const int
Default port the UDP discovery listener uses.
defaultHttpPort → const int
Default port the HTTP server listens on.
discoverMessage → const String
UDP broadcast message sent by clients looking for a server.
discoverResponsePrefix → const String
Prefix of the UDP response sent by the server, followed by a JSON payload. Format: XRAY_INSPECTOR_SERVER:<json> Example: XRAY_INSPECTOR_SERVER:{"port":7780,"platform":"ios"}