XRayLogInspector class
- Inheritance
-
- Object
- XRayInspector
- XRayLogInspector
Constructors
- XRayLogInspector({String title = 'Logs'})
Properties
- entries → List
-
no setter
-
entriesNotifier
→ ValueNotifier<
List> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
Methods
-
clear(
) → void -
debug(
String message) → void -
error(
String message) → void -
info(
String message) → void -
log(
String message, {String level = ImpaktfullLogInterceptorLevel.info}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
verbose(
String message) → void -
warning(
String message) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited