XRayNetworkCall class

Constructors

XRayNetworkCall({required String id, required String method, required String uri, required XRayNetworkCallStatus status, required DateTime startTime, Map<String, dynamic>? requestHeaders, dynamic requestBody, int? responseStatusCode, Map<String, dynamic>? responseHeaders, dynamic responseBody, DateTime? endTime, String? error})
const
XRayNetworkCall.fromJson(Map<String, dynamic> json)
factory

Properties

duration Duration?
no setter
durationMs int?
no setter
endTime DateTime?
final
error String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
method String
final
requestBody → dynamic
final
requestHeaders Map<String, dynamic>?
final
responseBody → dynamic
final
responseHeaders Map<String, dynamic>?
final
responseStatusCode int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime DateTime
final
status XRayNetworkCallStatus
final
uri String
final

Methods

copyWith({XRayNetworkCallStatus? status, Map<String, dynamic>? requestHeaders, dynamic requestBody, int? responseStatusCode, Map<String, dynamic>? responseHeaders, dynamic responseBody, DateTime? endTime, String? error}) XRayNetworkCall
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited