XRayNetworkInspector class

Inheritance

Constructors

XRayNetworkInspector({String title = 'Network'})

Properties

calls List
no setter
callsNotifier ValueNotifier<List>
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
no setterinherited
repository → NetworkCallsRepository
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

addListener(ImpaktfullNetworkInterceptorListener listener) → void
clear() → void
dispose() → void
findById(String id) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeListener(ImpaktfullNetworkInterceptorListener listener) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited