XRayInspectorServerConfig class
Constructors
-
XRayInspectorServerConfig({int discoveryPort = XRayInspectorProtocol.defaultDiscoveryPort, int httpPort = XRayInspectorProtocol.defaultHttpPort, List<
XRayInspector> inspectors = const []}) -
const
Properties
- discoveryPort → int
-
Port the UDP discovery listener uses. Defaults to XRayInspectorProtocol.defaultDiscoveryPort.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpPort → int
-
Port the HTTP server listens on. Defaults to XRayInspectorProtocol.defaultHttpPort.
final
-
inspectors
→ List<
XRayInspector> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited