XRayKeyValueInspector class
- Inheritance
-
- Object
- XRayInspector
- XRayKeyValueInspector
Constructors
- XRayKeyValueInspector({required ImpaktfullKeyValueSource source})
Properties
-
entriesNotifier
→ ValueNotifier<
List< InspectorKeyValueEntry> > -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → ImpaktfullKeyValueSource
-
final
- title → String
-
no setteroverride
Methods
-
clear(
) → void -
delete(
String key) → Future< void> -
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refresh(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
write(
String key, String value) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited